/* Track class implementation */
#include<stdio.h>
#include "track.h"


Track::Track()
{
	SectionCount = 0;
	NodeCount = 0;
}

Track::~Track()
{
}

unsigned long Track::GetNodeCount()
{
	return NodeCount;
}

unsigned long Track::GetSectionCount()
{
	return SectionCount;
}

bool Track::AddNode(unsigned long id, unsigned long to)
{

	if(NodeCount >= MAX_NODES)
	{
		return false;
	}

	nodes[NodeCount].ID = id;
	nodes[NodeCount].OwnerID = 0xffffffff;
	nodes[NodeCount].To = to;
	NodeCount++;

	return true;
}

bool Track::AddSection(unsigned long	id,
					   double			ax,
					   double			ay,
					   double			bx,
					   double			by,
					   double			radius,
					   unsigned long	nodeA,
					   unsigned long	nodeB)
{

	if(SectionCount >= MAX_SECTIONS)
	{
		return false;
	}

	sections[SectionCount].ID = id;
	sections[SectionCount].Ax = ax;
	sections[SectionCount].Ay = ay;
	sections[SectionCount].Bx = bx;
	sections[SectionCount].By = by;
	sections[SectionCount].NodeA = nodeA;
	sections[SectionCount].NodeB = nodeB;
	sections[SectionCount].OwnerID = 0xffffffff;
	SectionCount++;

	return false;

}

bool Track::LoadConfigFromFile(char * filename)
{

	FILE * file = fopen(filename, "at");
	if(file == NULL)
	{
		return false;
	}

	char buffer[SIZE_TRACKCONFIG];

	while(fgets(buffer, SIZE_TRACKCONFIG, file))
	{
		unsigned int id, nodea, nodeb, to;
		float ax,ay, bx, by, r;
		if(sscanf(buffer, "SECTION ID=%u AX=%f AY=%f BX=%f BY=%f R=%f NODEA=%u NODEB=%u",
							&id, &ax, &ay, &bx, &by, &r, &nodea, &nodeb) == 8)
		{
			AddSection(id, ax, ay, bx, by, r, nodea, nodeb);
		}
		else if(sscanf(buffer, "NODE ID=%u TO=%u", &id, &to) == 2)
		{
			AddNode(id, to);
		}
		else
		{
			/*invalid line in file, skipping*/
		}
	}

	fclose(file);

	return true;
	
}


Section Track::GetSectionByIndex(unsigned long index)
{
	return sections[index];
}

Node Track::GetNodeByIndex(unsigned long index)
{
	return nodes[index];
}




